==> haskell-transformers-base-0.4.6-264-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-4HhhwkoiB3B6zaDCU5wSX9
key:                  transformers-base-0.4.6-4HhhwkoiB3B6zaDCU5wSX9
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  77841f1f479c986fceabd82d26e5130a
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-4HhhwkoiB3B6zaDCU5wSX9
depends:
    base-4.18.2.1 base-orphans-0.9.3-HILbhTDEXJYIGnbSbNtfR4 stm-2.5.1.0
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.6-266-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-9SmG3ZLPK2vKQjQF6vx3D4
key:                  transformers-base-0.4.6-9SmG3ZLPK2vKQjQF6vx3D4
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  541ab829b05d96d8c8777883d49fcf0a
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-9SmG3ZLPK2vKQjQF6vx3D4
depends:
    base-4.18.2.1 base-orphans-0.9.3-1Kgd52LA8shBrElWhAbQ stm-2.5.1.0
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
